@@ -10,7 +10,7 @@ use Data::Dumper;
 
 # ABSTRACT: Bulk Load for Postgres with ability to skip bad records.
 
-our $VERSION='2.05';
+our $VERSION='2.06';
 
 sub new ( $Class, %args ) {
 	for my $required ( qw/ pg errorfile/ ) {
@@ -106,33 +106,36 @@ Pg::BulkLoad - Bulk Load for Postgres with ability to skip bad records.
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 Pg::BulkLoad
 
 Load Comma and Tab Delimited files into Postgres, skipping bad records.
 
-=head1 VERSION 2.05
+=head1 VERSION 2.06
 
 =head1 Synopsis
 
+This example will take a table name followed by file names (wildcards allowed) from the command
+line and load the data.
+
  Shell> split -l 50000 -a 3 -d mydata.csv load
- Shell> myloadscript.pl load*
+ Shell> myloadscript.pl tablename load*
 
  === myloadscript.pl ===
 
-  use Pg::BulkCopy;
+  use Pg::BulkLoad;
 
   my $pgc = Pg::BulkLoad->new(
-    pg => DBI->connect("dbi:Pg:dbname=$dbname", '', '', {AutoCommit => 0}),
+    pg => DBI->connect("dbi:Pg:dbname=$dbname", $username, $password, {AutoCommit => 0}),
     errorfile => '/tmp/pgbulk.error',
     errorlimit => 500,
   );
 
-  # to take a table name followed by the file names from the command line
-  # use the following:
   my $table = shift @ARGV;
-  for my $file ( @ARGV ) { $pgc->load( $file, $table, 'csv' ) }
+  my @files = map { `ls -b $_`} @ARGV ;
+  chomp @files;
+  for my $file ( @files ) { $pgc->load( $file, $table, 'csv' ) }
 
 =head2 new
 
@@ -180,6 +183,19 @@ Since Pg::Bulkload passes all of the work to copy it is subject to the limitatio
 
 The internal error counting is for the life of an instance not per data file. If you have 100 source files an error limit of 500 and there are 1000 errors in your source you will likely get about half the data loaded before this module quits. You should be prepared to deal with the consequences of a partial load.
 
+=head2 Extra Help for Perl Novices
+
+=head3 DBI Connection
+
+The example assumes that you'll set variables for your dbname, user and password. Optionally you could make them command line parameters with this code:
+
+  my $dbname = shift @ARGV;
+  my $username = shift @ARGV;
+  my $password = shift @ARGV;
+  my $tablename = shift @ARGV;
+
+Or you could assign a value to any of those. The keyword B<my> is variable declaration, B<@ARGV> is Perl's name for the command line arguments.
+
 =head2 History
 
 My first CPAN module was Pg::BulkCopy, because I had this problem. I found something better that was written in C, so I deprecated my original module which needed a rewrite. Sometimes the utility I switched to doesn't want to compile, so I got tired of that, still had my original problem of getting a lot of data from an external source that has a certain amount of errors, and is creative in finding new ways get bad records past my preprocessor. Pg::BulkCopy wanted to be an import/export utility, Pg::BulkLoad only deals with the core issue of getting the good data loaded.
